<?php

namespace Drupal\Tests\block\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests form validation.
 *
 * @group flowbite_sdc
 */
class FormTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['flowbite_sdc'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->drupalLogin($this->drupalCreateUser([
      'administer site configuration',
    ]));
  }

  /**
   * Check valid CSS CDN form submit.
   */
  public function testValidCssForm(): void {
    $this->drupalGet('/admin/config/system/flowbite');

    $edit = [
      'css_enable' => TRUE,
      'css_url' => 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $config = $this->config('flowbite_sdc.cdn_settings');

    $this->assertTrue($config->get('css.enable'));
    $this->assertFalse($config->get('js.enable'));

    $this->assertEquals($edit['css_url'], $config->get('css.url'));
    $this->assertEquals('', $config->get('js.url'));
  }

  /**
   * Check valid JS CDN form submit.
   */
  public function testValidJsForm(): void {
    $this->drupalGet('/admin/config/system/flowbite');

    $edit = [
      'js_enable' => TRUE,
      'js_url' => 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $config = $this->config('flowbite_sdc.cdn_settings');

    $this->assertFalse($config->get('css.enable'));
    $this->assertTrue($config->get('js.enable'));

    $this->assertEquals('', $config->get('css.url'));
    $this->assertEquals($edit['js_url'], $config->get('js.url'));
  }

  /**
   * Check valid CSS and JS CDN form submit.
   */
  public function testValidCssAndJsForm(): void {
    $this->drupalGet('/admin/config/system/flowbite');

    $edit = [
      'css_enable' => TRUE,
      'css_url' => 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css',
      'js_enable' => TRUE,
      'js_url' => 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $config = $this->config('flowbite_sdc.cdn_settings');

    $this->assertTrue($config->get('css.enable'));
    $this->assertTrue($config->get('js.enable'));

    $this->assertEquals($edit['css_url'], $config->get('css.url'));
    $this->assertEquals($edit['js_url'], $config->get('js.url'));
  }

  /**
   * Check empty CSS CDN form submit.
   */
  public function testInvalidCssForm(): void {
    $this->drupalGet('/admin/config/system/flowbite');

    $edit = [
      'css_enable' => TRUE,
      'css_url' => '',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('CDN URL for CSS is required.');
  }

  /**
   * Check empty JS CDN form submit.
   */
  public function testInvalidJsForm(): void {
    $this->drupalGet('/admin/config/system/flowbite');

    $edit = [
      'js_enable' => TRUE,
      'js_url' => '',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('CDN URL for JS is required.');
  }

  /**
   * Check empty CSS and JS CDN form submit.
   */
  public function testInvalidCssAndJsForm(): void {
    $this->drupalGet('/admin/config/system/flowbite');

    $edit = [
      'js_enable' => TRUE,
      'js_url' => '',
      'css_enable' => TRUE,
      'css_url' => '',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('CDN URL for CSS is required.');
    $this->assertSession()->pageTextContains('CDN URL for JS is required.');
  }

  /**
   * Check invalid host for CSS CDN form submit.
   */
  public function testInvalidCssHostForm() {
    $this->drupalGet('/admin/config/system/flowbite');
    $edit = [
      'css_enable' => TRUE,
      'css_url' => 'http://example.com/style.css',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('CDN URL for CSS is invalid and should be from jsdelivr.net domain');
  }

}
