<?php

namespace Drupal\Tests\block\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests does the library is attached.
 *
 * @group flowbite_sdc
 */
class LibraryTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['flowbite_sdc'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Test if there are no Flowbite references in the response.
   */
  public function testInstall(): void {
    $this->drupalGet('<front>');
    $this->assertSession()->responseNotContains('npm/flowbite');
  }

  /**
   * Check if CSS CDN is included in response.
   */
  public function testIncludeCssCdn(): void {
    $this->config('flowbite_sdc.cdn_settings')
      ->set('css.enable', TRUE)
      ->set('css.url', 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css')
      ->save();

    drupal_flush_all_caches();

    $this->drupalGet('<front>');
    $this->assertSession()->responseContains('https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css');
  }

  /**
   * Check if JS CDN is included in response.
   */
  public function testIncludeJsCdn(): void {
    $this->config('flowbite_sdc.cdn_settings')
      ->set('js.enable', TRUE)
      ->set('js.url', 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js')
      ->save();

    drupal_flush_all_caches();

    $this->drupalGet('<front>');
    $this->assertSession()->responseContains('https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js');
  }

  /**
   * Check if JS CDN is included in response.
   */
  public function testIncludeCssAndJsCdn(): void {
    $this->config('flowbite_sdc.cdn_settings')
      ->set('css.enable', TRUE)
      ->set('css.url', 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css')
      ->set('js.enable', TRUE)
      ->set('js.url', 'https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js')
      ->save();

    drupal_flush_all_caches();

    $this->drupalGet('<front>');
    $this->assertSession()->responseContains('https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css');
    $this->assertSession()->responseContains('https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js');
  }

}
